@@ -177,10 +177,15 @@ class MediaShowListingView(BrowserView):
         resultArray = []
         
         #Python to JSON encoding
-        for res in results:
-            if self.getMediaURL(res.getObject()) != "":
-                resultArray.append({"url": res.getURL(), "UID": res["UID"]})
-
+        if not recursiveMode:
+            for res in results:
+                if self.getMediaURL(res.getObject()) != "" and res.getObject() != self.context:
+                    resultArray.append({"url": res.getURL(), "UID": res["UID"]})
+        else:
+            for res in results:
+                if self.getMediaURL(res.getObject()) != "" and res.getObject() != self.context and res.portal_type != 'Folder':
+                    resultArray.append({"url": res.getURL(), "UID": res["UID"]})
+        
         jsonStr = json.dumps(resultArray[:100])
         
         if callback is not None:
